@@ -7,7 +7,7 @@
 class KGpgImportTest: public QObject
 {
 	Q_OBJECT
-private slots:
+private Q_SLOTS:
 	void init();
 	void testImportTextKey();
 	void testImportIdsAll();
